##  Hiding Inventory Updates
Diagrams represent a snapshot of the inventory at the time they were last saved. Changes in the underlying inventory, including fact sheets, relations, or other elements, aren't applied automatically. Update icons highlight where items have changed since the diagram was last saved, and you can hide these icons while viewing the diagram.
To hide update icons while viewing:
  1. Hover over the diagram to display the toolbar.
  2. Choose Hide inventory updates.
The update icons are removed from the current view. If you navigate to a different diagram or refresh the page, the icons will reappear.


For information about managing inventory updates, see [Applying Inventory Updates](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__section_ktk_hrk_dgc).
**Note**
This behavior applies to saved diagrams. Diagram templates always reflect the current state of the inventory and don’t require manual updates.
Related Information
[Free Draw Diagrams](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD)
[Data Flow Diagrams](https://help.sap.com/docs/leanix/ea/data-flow?locale=en-US&state=PRODUCTION&version=CLOUD)
[Previewing Templates and Creating Diagrams from Templates](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates?locale=en-US&state=PRODUCTION&version=CLOUD "Template previews provide dynamic, real-time diagrams of your current inventory. Use this feature to visualize data, collaborate with stakeholders, and generate static diagrams as needed.")
[Managing Diagram Versions, Importing, and Exporting](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting?locale=en-US&state=PRODUCTION&version=CLOUD "Diagram versioning, import, and export features enable users to track changes, restore or compare diagram versions, and seamlessly transfer diagrams between tools such as draw.io, Lucidchart, and Visio. These capabilities support collaboration, version control, and interoperability across diagramming platforms.")
